local _, NS = ...

function NS:BuildOptions(name, addon)
  return {
    name = name,
    handler = addon,
    type = "group",
    set = "SetOption",
    get = "GetOption",
    args = {
      description = {
        order = 1,
        type = "description",
        name = "OrganizedPanic helps your party members avoid casting expensive cooldowns at the same time."
      },
      display_settings = {
        order = 2,
        type = "group",
        name = "Display Settings",
        inline = true,
        args = {
          help = {
            type = "description",
            name = "The display of the flashing border can be customized by changing the options below.",
            order = 1,
          },
          flash_border = {
            order = 2,
            type = "toggle",
            name = "Flash Border",
            desc = "Flash border when another player casts a cooldown?",
            arg = "flashBorder",
          },
          border_color = {
            order = 3,
            type = "color",
            name = "Border color",
            desc = "The color of the flashing border.",
            set = "SetBorderColor",
            get = "GetBorderColor"
          },
        }
      },
      sound_settings = {
        order = 3,
        type = "group",
        name = "Sound Settings",
        inline = true,
        args = {
          help = {
            order = 1,
            type = "description",
            name = "Sounds can be customized by changing the options below.",
          },
          play_sound = {
            order = 2,
            type = "toggle",
            name = "Play Sound",
            desc = "Play sound when another player casts a cooldown?",
            arg = "playSound",
          },
          sound_select = {
            order = 3,
            type = "select",
            name = "Sound",
            desc = "The sound to play when another layer casts a cooldown.",
            arg = "sound",
            values = {
              ["auctionhouse"] = "Auction House",
              ["raidwarning"] = "Raid Warning",
              ["raidbosswarning"] = "Raid Boss Warning",
              ["raidbosswhisperwarning"] = "Raid Boss Whisper Warning",
            }
          },
          test_sound = {
            type = "execute",
            order = 4,
            name = "Play",
            desc = "Test the selected sound.",
            func = function(info)
              PlaySoundFile(OP_SOUNDS[info.handler.db.profile.sound], "Master")
            end
          },
        },
      },
      help_group = {
        order = 4,
        type = "group",
        name = "Chat Commands",
        inline = true,
        args = {
          group_1 = {
            order = 1,
            type = "group",
            name = "",
            inline = true,
            args = {
              help_text_1 = {
                order = 1,
                type = "description",
                name = "/op todo - TODO :)"
              },
            },
          },
        },
      },
      debug_group = {
        order = 5,
        type = "group",
        name = "Debug Options",
        inline = true,
        args = {
          group_1 = {
            order = 1,
            type = "group",
            name = "",
            inline = true,
            args = {
              debug_toggle = {
                order = 2,
                type = "toggle",
                name = "Debug Mode",
                desc = "Show lots of annoying debug output?",
                arg = "debug",
              },
            },
          },
        },
      },
    }
  }
end
